package de.ozgcloud.antragsraum.events;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestClient;

import de.ozgcloud.antragsraum.WebConfiguration;
import de.ozgcloud.antragsraum.proxy.InfoGrpcInformationByIdResponse;
import de.ozgcloud.antragsraum.proxy.InfoGrpcInformationResponse;
import de.ozgcloud.common.errorhandling.TechnicalException;

@Component
class NachrichtEventRestClient {
	static final String INFORMATION_LIST_ENDPOINT = "api/v1/informations/{postfachId}";
	static final String INFORMATION_ENDPOINT = "api/v1/information/{id}";

	private final RestClient client;

	NachrichtEventRestClient(@Qualifier(WebConfiguration.INFO_MANAGER_REST_CLIENT) RestClient client) {
		this.client = client;
	}

	InfoGrpcInformationByIdResponse getNachrichtEventById(String id) {
		return get(INFORMATION_ENDPOINT, InfoGrpcInformationByIdResponse.class, id);
	}

	InfoGrpcInformationResponse getNachrichtEventsByPostfach(String postfachId) {
		return get(INFORMATION_LIST_ENDPOINT, InfoGrpcInformationResponse.class, postfachId);
	}

	<T> T get(String endpoint, Class<T> bodyType, Object... uriParams) {
		try {
			return client.get()
			  .uri(endpoint, uriParams)
			  .retrieve()
			  .toEntity(bodyType)
			  .getBody();
		} catch (Exception e) {
			throw new TechnicalException("Error retrieving data from grpc using restclient.", e);
		}
	}
}