/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.nachricht;

import java.util.List;

import jakarta.validation.Valid;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import de.ozgcloud.antragsraum.command.CommandReference;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;

@RestController
@RequestMapping(NachrichtenController.PATH)
@RequiredArgsConstructor
@SecurityRequirement(name = "security_auth")
class NachrichtenController {
	static final String PATH = "/api"; // NOSONAR

	private final @NonNull NachrichtenService service;

	@Operation(summary = "Load all Rueckfragen Headers of a Postfach")
	@GetMapping(value = "/rueckfragen/{postfachId}", produces = MediaType.APPLICATION_JSON_VALUE)
	List<RueckfrageHeader> getRueckfrageHeadersOfPostfach(
	  @Parameter(description = "The id of the postfach", example = "28721c6f-b78f-4d5c-a048-19fd2fc429d2") @PathVariable String postfachId) {
		return service.getRueckfrageHeadersOfPostfach(postfachId);
	}

	@Operation(summary = "Load a Rueckfrage by id")
	@GetMapping(value = "/rueckfrage/{rueckfrageId}/{nachrichtEventId}", produces = MediaType.APPLICATION_JSON_VALUE)
	Rueckfrage getRueckfrage(
	  @Parameter(description = "The id of the Rueckfrage", example = "1258ad3f46811d04010f22ab") @PathVariable String rueckfrageId,
	  @Parameter(description = "The id of the NachrichtEvent in the InfoManager the rueckfrage belongs to", example = "60af924b4f1a2560298b4567")
	  @PathVariable String nachrichtEventId) {
		return service.getRueckfrage(rueckfrageId, nachrichtEventId);
	}

	@Operation(summary = "Send the reply to the Rueckfrage into the ozg cloud")
	@PutMapping(value = "/antwort", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
	CommandReference sendNachricht(@Parameter(description = "The Nachricht content as JSON") @RequestBody @Valid ReplyNachricht nachricht) {
		return service.sendRueckfrageAnswer(nachricht);
	}
}
